==> k3d_0.4.3.0.orig.tar.gz: k3d-0.4.3.0/k3dsdk/ishader_collection.h <==
#ifndef K3DSDK_ISHADER_COLLECTION_H
#define K3DSDK_ISHADER_COLLECTION_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\brief Declares ishader_collection, an abstract interface for a collection of RenderMan shaders
		\author Tim Shead (tshead@k-3d.com)
*/

#include "iunknown.h"

#ifndef SDPSL_H
#include <sdpsl/sdpsl.h>
#endif // !SDPSL_H

namespace k3d
{

/// Abstract interface for a collection of RenderMan shaders
class ishader_collection :
	public virtual iunknown
{
public:
	virtual const sdpsl::shaders_t& shaders() = 0;
	
protected:
	ishader_collection() {}
	ishader_collection(const ishader_collection& RHS) {}
	ishader_collection& operator=(const ishader_collection& RHS) { return *this; }
	virtual ~ishader_collection() {}
};

} // namespace k3d

#endif // K3DSDK_ISHADER_COLLECTION_H

==> k3d_0.5.0.35.orig.tar.gz: k3d-0.5.0.35/k3dsdk/ishader_collection.h <==
#ifndef K3DSDK_ISHADER_COLLECTION_H
#define K3DSDK_ISHADER_COLLECTION_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\brief Declares ishader_collection, an abstract interface for a collection of RenderMan shaders
		\author Tim Shead (tshead@k-3d.com)
*/

#include "iunknown.h"
#include "sl.h"

namespace k3d
{

/// Abstract interface for a collection of RenderMan shaders
class ishader_collection :
	public virtual iunknown
{
public:
	virtual const sl::shaders_t& shaders() = 0;
	
protected:
	ishader_collection() {}
	ishader_collection(const ishader_collection& RHS) {}
	ishader_collection& operator=(const ishader_collection& RHS) { return *this; }
	virtual ~ishader_collection() {}
};

} // namespace k3d

#endif // K3DSDK_ISHADER_COLLECTION_H
